@@ -8,29 +8,29 @@ extends 'API::Wunderlist::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Wunderlist (Perl)',
 );
 
 has client_id => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has access_token => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 1,
 );
 
@@ -133,7 +133,7 @@ API::Wunderlist - Perl 5 API wrapper for Wunderlist
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -390,9 +390,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $wunderlist->action('head', %args);   # HEAD request
-    $wunderlist->action('optons', %args); # OPTIONS request
-    $wunderlist->action('patch', %args);  # PATCH request
+    $wunderlist->action('head', %args);    # HEAD request
+    $wunderlist->action('options', %args); # OPTIONS request
+    $wunderlist->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
